// scripthost-core - version 1.1.0
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/** @internal */
function isObject(thing) {
    return typeof thing === "object" && thing !== null;
}
/** @internal */
function isString(thing) {
    return hasType(thing, "string");
}
const hasType = (thing, ...type) => type.includes(typeof thing);

/**
 * Determines whether something is a {@link GenericMessage}
 * @param thing - The thing to test
 * @param type - Optionally specifies the message type to test
 * @public
 */
function isGenericMessage(thing, type) {
    if (!isObject(thing)) {
        return false;
    }
    if (!isString(thing["messageId"])) {
        return false;
    }
    if (isString(type)) {
        return thing["type"] === type;
    }
    else {
        return isString(thing["type"]);
    }
}

/**
 * Determines whether something is a {@link GenericResponse}
 * @param thing - The thing to test
 * @param type - Optionally specifies the message type to test
 * @public
 */
function isGenericResponse(thing, type) {
    return (isGenericMessage(thing, type) &&
        isString(thing["inResponseTo"]));
}

/**
 * Determines whether something is a {@link InitializeRequest}
 * @public
 */
function isInitializeRequest(thing) {
    return isGenericMessage(thing, "init");
}

/**
 * Determines whether something is a {@link InitializeResponse}
 * @public
 */
function isInitializeResponse(thing) {
    return isGenericResponse(thing, "ready");
}

/**
 * Determines whether something is a {@link PingRequest}
 * @public
 */
function isPingRequest(thing) {
    return isGenericMessage(thing, "ping");
}

/**
 * Determines whether something is a {@link PingResponse}
 * @public
 */
function isPingResponse(thing) {
    return isGenericResponse(thing, "pong");
}

/**
 * Determines whether something is an {@link ErrorResponse}
 * @public
 */
function isErrorResponse(thing) {
    return isGenericResponse(thing, "error");
}

/**
 * Determines whether something is a {@link EvaluateScriptRequest}
 * @public
 */
function isEvaluateScriptRequest(thing) {
    return isGenericMessage(thing, "eval") && isString(thing["script"]);
}

/**
 * Determines whether something is a {@link EvaluateScriptResponse}
 * @public
 */
function isEvaluateScriptResponse(thing) {
    return isGenericResponse(thing, "result");
}

/**
 * Determines whether something is a {@link FunctionCallRequest}
 * @public
 */
function isFunctionCallRequest(thing) {
    return isGenericMessage(thing, "call") && isString(thing["key"]);
}

/**
 * Determines whether something is a {@link FunctionCallResponse}
 * @public
 */
function isFunctionCallResponse(thing) {
    return isGenericResponse(thing, "return");
}

/**
 * Determines whether something is a {@link YieldRequest}
 * @public
 */
function isYieldRequest(thing) {
    return isGenericMessage(thing, "yield");
}

/**
 * Determines whether something is a {@link YieldResponse}
 * @public
 */
function isYieldResponse(thing) {
    return isGenericResponse(thing, "continue");
}

exports.isErrorResponse = isErrorResponse;
exports.isEvaluateScriptRequest = isEvaluateScriptRequest;
exports.isEvaluateScriptResponse = isEvaluateScriptResponse;
exports.isFunctionCallRequest = isFunctionCallRequest;
exports.isFunctionCallResponse = isFunctionCallResponse;
exports.isGenericMessage = isGenericMessage;
exports.isGenericResponse = isGenericResponse;
exports.isInitializeRequest = isInitializeRequest;
exports.isInitializeResponse = isInitializeResponse;
exports.isPingRequest = isPingRequest;
exports.isPingResponse = isPingResponse;
exports.isYieldRequest = isYieldRequest;
exports.isYieldResponse = isYieldResponse;
//# sourceMappingURL=scripthost-core.js.map
